summaryrefslogtreecommitdiffstats
path: root/src/ktechlab.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/ktechlab.h')
-rw-r--r--src/ktechlab.h51
1 files changed, 26 insertions, 25 deletions
diff --git a/src/ktechlab.h b/src/ktechlab.h
index b69d0c2..d2bf51a 100644
--- a/src/ktechlab.h
+++ b/src/ktechlab.h
@@ -26,7 +26,7 @@ class ProjectManager;
class View;
class ViewContainer;
-typedef QValueList< QGuardedPtr<ViewContainer> > ViewContainerList;
+typedef TQValueList< TQGuardedPtr<ViewContainer> > ViewContainerList;
class KAction;
class RecentFilesAction;
@@ -34,7 +34,7 @@ class KTabWidget;
class KToolBar;
class KToggleAction;
class KURL;
-class QLabel;
+class TQLabel;
/**
* This class serves as the main window for KTechlab. It handles the
@@ -46,6 +46,7 @@ class QLabel;
class KTechlab : public KateMDI::MainWindow
{
Q_OBJECT
+ TQ_OBJECT
public:
KTechlab();
~KTechlab();
@@ -53,7 +54,7 @@ class KTechlab : public KateMDI::MainWindow
/**
* Returns a pointer to an action with the given name.
*/
- KAction * action( const QString & name ) const;
+ KAction * action( const TQString & name ) const;
/**
* Returns a URL from a Open File dialog (with all ktechlab related file
* types allowed).
@@ -62,10 +63,10 @@ class KTechlab : public KateMDI::MainWindow
/**
* Returns a list of the recently opened/saved files
*/
- QStringList recentFiles();
+ TQStringList recentFiles();
/**
* The tab and window captions will get updated when we have re-entered
- * the Qt event loop.
+ * the TQt event loop.
*/
void requestUpdateCaptions();
/**
@@ -111,13 +112,13 @@ class KTechlab : public KateMDI::MainWindow
/**
* The user right clicked on a tab item.
*/
- void slotTabContext( QWidget* widget,const QPoint & pos );
+ void slotTabContext( TQWidget* widget,const TQPoint & pos );
void slotDragContextActivated( int id );
/**
* The user clicked on an item in the tab-menu (from right clicking).
*/
void slotTabContextActivated( int id );
- void slotChangeStatusbar(const QString& text);
+ void slotChangeStatusbar(const TQString& text);
void load(const KURL& url);
void slotUpdateConfiguration();
/**
@@ -137,10 +138,10 @@ class KTechlab : public KateMDI::MainWindow
protected:
/**
- * Overridden virtuals for Qt drag 'n drop (XDND)
+ * Overridden virtuals for TQt drag 'n drop (XDND)
*/
- virtual void dragEnterEvent(QDragEnterEvent *event);
- virtual void dropEvent(QDropEvent *event);
+ virtual void dragEnterEvent(TQDragEnterEvent *event);
+ virtual void dropEvent(TQDropEvent *event);
/**
* This function is called when it is time for the app to save its
* properties for session management purposes.
@@ -160,11 +161,11 @@ class KTechlab : public KateMDI::MainWindow
virtual bool queryClose();
protected slots:
- void slotViewContainerActivated( QWidget * viewContainer );
- void slotTabDragEvent( const QDragMoveEvent *e, bool &accept );
- void slotTabDragInitiate( QWidget *widget );
- void slotTabReceivedDropEvent( QDropEvent *e );
- void slotTabReceivedDropEvent( QWidget *widget, QDropEvent *e );
+ void slotViewContainerActivated( TQWidget * viewContainer );
+ void slotTabDragEvent( const TQDragMoveEvent *e, bool &accept );
+ void slotTabDragInitiate( TQWidget *widget );
+ void slotTabReceivedDropEvent( TQDropEvent *e );
+ void slotTabReceivedDropEvent( TQWidget *widget, TQDropEvent *e );
void slotUpdateTabWidget();
/**
* Updates the tab and window captions from what is currently open and
@@ -174,11 +175,11 @@ class KTechlab : public KateMDI::MainWindow
private slots:
/**
* Called from a QTimer timeout (which should be after the toolbars have
* finished constructing themselves).
*/
void hideToolBarOverlay();
- void slotViewContainerDestroyed( QObject * obj );
+ void slotViewContainerDestroyed( TQObject * obj );
void slotFileNewAssembly();
void slotFileNewMicrobe();
@@ -226,17 +227,17 @@ class KTechlab : public KateMDI::MainWindow
RecentFilesAction * m_recentProjects;
KToggleAction * m_statusbarAction;
KTabWidget * m_pViewContainerTabWidget;
- QString m_lastStatusBarMessage;
- QValueList<KXMLGUIClient*> m_noRemoveGUIClients;
- QLabel * m_pToolBarOverlayLabel;
+ TQString m_lastStatusBarMessage;
+ TQValueList<KXMLGUIClient*> m_noRemoveGUIClients;
+ TQLabel * m_pToolBarOverlayLabel;
bool m_bIsShown; // Set true when show() is called
ViewContainerList m_viewContainerList;
- QTimer * m_pUpdateCaptionsTimer;
+ TQTimer * m_pUpdateCaptionsTimer;
- QGuardedPtr<ViewContainer> m_pContextMenuContainer;
- QGuardedPtr<ViewContainer> m_pFocusedContainer;
- QGuardedPtr<ViewContainer> m_pContainerDropSource;
- QGuardedPtr<ViewContainer> m_pContainerDropReceived;
+ TQGuardedPtr<ViewContainer> m_pContextMenuContainer;
+ TQGuardedPtr<ViewContainer> m_pFocusedContainer;
+ TQGuardedPtr<ViewContainer> m_pContainerDropSource;
+ TQGuardedPtr<ViewContainer> m_pContainerDropReceived;
};
#endif // KTECHLAB_H
@@ -174,11 +175,11 @@ class KTechlab : public KateMDI::MainWindow
private slots:
/**
- * Called from a QTimer timeout (which should be after the toolbars have
+ * Called from a TQTimer timeout (which should be after the toolbars have
* finished constructing themselves).
*/